//
// This file is minified and put in siteSlicer.js
//
// Prevent the sliced page from scrolling the parent
if (document.addEventListener)
{
	document.addEventListener('touchmove', function(e)
	{
		e.preventDefault();
	});
}

function sendSiteSliceProxyMessage  (message, value) {
    /// <summary>Sends a message via the proxy to the parent page</summary>
    /// <param name="message" type="String">The message name</param>
    /// <param name="value" type="String">The value of the message</param>
	var msgstr='{\"message\":\"' +message +'\",\"value\":\"' +value.replace(/\'/g,'\\\'') +'\"}';
	parent.postMessage(msgstr,'*');
}

function siteSliceScriptPostLink (link)
{
	sendSiteSliceProxyMessage('openLink',link);
}
	
(function(xpath, pageId) 
{
    /// <summary>Monitors for an element</summary>
    /// <param name="xpath" type="String">The xpath to the element to monitor</param>
    /// <param name="pageId" type="String">Id of the recieving page</param>
    /// <param name="callbackId" type="String">Id of the recieving function</param>

    var getElementFromXPath = function (xPath) {
        /// <summary>Locates an element based on an xpath</summary>
        /// <param name="xPath" type="String">The xpath to the element</param>
        /// <returns type="DomElement" />
        var elm = document.body;
		if (!xPath)
		{
			return;
		}

        var tokens = xPath.split('/');
        for (var i = 0; i < tokens.length; i++) {
            if (!elm) 
			{
				return null;
			}
            var sToken = tokens[i];
            var iPos = sToken.indexOf('[');
            var sTag = sToken.substring(0, iPos);
            var sAttToken = sToken.substring(iPos + 1, sToken.length - 1);
            iPos = sAttToken.indexOf('=');
            if (iPos > 0) {
                var sName = sAttToken.substring(iPos + 2, sAttToken.length - 1);
                elm = document.getElementById(sName);
                continue;
            }
            else {
                var idx = parseInt(sAttToken);
                elm = elm.getElementsByTagName(sTag)[idx];
            }
        }
        return elm;
    };

     var fixLinks = function ()
	 {
        /// <summary>Fixes all links in page to open in new window</summary>
		var link;

        var items = document.getElementsByTagName('a');
        for (var i = 0; i < items.length; i++) {
            //scan all a items that don't have a javascript: prefix
            if (items[i].href && items[i].href.toLowerCase().substring(0, 11) !== 'javascript:') 
			{
				link = items[i].href;
                items[i].href = 'javascript:siteSliceScriptPostLink(\''+link+'\');';
            }
        }
        items = document.getElementsByTagName('form');
        for (var i = 0; i < items.length; i++) {
            //set all form targets to open in new window
            items[i].target = '_blank';
        }
    };


    //find our element
    var elm = getElementFromXPath(xpath);


    //poller id
    var checkPoller = 0;

    window.stopCheck = function () {
        /// <summary>Called by the parent window to notify us to stop testing</summary>
        window.clearInterval(checkPoller);
    };
    window.recievedReply = function () {
        /// <summary>Called by the patent window to notify us that the connection is open</summary>
        fixLinks();
        window.setInterval(fixLinks, 3000);
    };
    //the rect of the element
    var lastRect = { left: 0, top: 0, height: 0, width: 0, bottom: 0, right: 0 };

	var failures = 0;
	var tries = 0;
    var fSend = function (force) {
        /// <summary>searches for the element, and sends the appropriate message to the parent</summary>
        /// <param name="force" type="Boolean">By default a message is sent only if the size was changed, use
        ///force = true to send anyway</param>
        try {

            //find our element
            elm = getElementFromXPath(xpath);
            if (!elm) {
                //notify our parent that the item could not be found
                sendSiteSliceProxyMessage('notFound', 'not found');
				failures++;
				if (failures>30)
				{
					window.clearInterval(checkPoller);
				}
                return;
            }
            //get the elements rectangle
            var rc = elm.getBoundingClientRect(); 
            if (force ||
            (rc.left !== lastRect.left ||
            rc.top !== lastRect.top ||
            rc.width !== lastRect.width ||
            rc.height !== lastRect.height)
            ) {
            //if we are different in size (or force) then send the message
                var msg = '{left:' + rc.left + ',top:' + rc.top + ',width:' + rc.width + ',height:' + rc.height + ',bottom:' + rc.bottom + ',right:' + rc.right + '}';
                //sends a prefix.setPosition message
                sendSiteSliceProxyMessage('setPosition', msg);
				window.clearInterval(checkPoller);
            }
            lastRect = rc;
			tries++;
			if (tries>30)
			{
				window.clearInterval(checkPoller);
			}
        } catch (ex) {
            //alert(ex);
        }
    };
    //start by force testing
    fSend(true);
    //set a poller to test for dom changes
    checkPoller = window.setInterval(function () { fSend(false); fixLinks(); window.top=window;}, 200);
})();
//end of copy ('path', 'message','callbackId',);
